@@ -1,11 +1,11 @@
 #                       Copyright 2020 Saad Mairaj
-# 
+#
 #    Licensed under the Apache License, Version 2.0 (the "License");
 #    you may not use this file except in compliance with the License.
 #    You may obtain a copy of the License at
-# 
+#
 #        http://www.apache.org/licenses/LICENSE-2.0
-# 
+#
 #    Unless required by applicable law or agreed to in writing, software
 #    distributed under the License is distributed on an "AS IS" BASIS,
 #    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
@@ -13,16 +13,42 @@
 #    limitations under the License.
 
 import re
+import sys
 import ast
-import pickle as pkl
-import tkinter as _TK
 import tkmacosx
+import pickle as pkl
+
+if sys.version_info.major == 2:
+    import Tkinter as _TK
+elif sys.version_info.major == 3:
+    import tkinter as _TK
 
 
 # Modified Misc._options(...) to make ColorVar work with tkinter
 _all_traces_colorvar = {}
 
 
+def destroy(self):
+    """Internal function.
+
+    Delete all Tcl commands created for
+    this widget in the Tcl interpreter."""
+    if self._tclCommands is not None:
+        # Deletes the widget from the _all_traces_colorvar 
+        # and deletes the traces too.
+        if self in dict(_all_traces_colorvar.keys()).keys():
+            d = dict(_all_traces_colorvar.keys())
+            key = (self, d[self])
+            var, cbname = _all_traces_colorvar[key]
+            var.trace_vdelete('w', cbname)
+            _all_traces_colorvar.pop(key)
+        #--------------------------------------
+        for name in self._tclCommands:
+            # print '- Tkinter: deleted command', name
+            self.tk.deletecommand(name)
+        self._tclCommands = None
+
+
 def _configure(self, cmd, cnf, kw):
     """Internal function."""
     if kw:
@@ -47,13 +73,13 @@ def _configure(self, cmd, cnf, kw):
                       'foreground'):
                 if isinstance(cnf_copy.get(i), _TK.Variable):
                     var = cnf_copy[i]
-                    cbname = var.trace_add('write', lambda *a,
-                                           cls=self, opt=i,
-                                           tagId=tag, var=var:
-                                           cls.itemconfig(tagId, {opt: var.get()}))
+                    cbname = var.trace_variable('w', lambda a, b, c,
+                                                cls=self, opt=i,
+                                                tagId=tag, var=var:
+                                                cls.itemconfig(tagId, {opt: var.get()}))
                     if (self, (i, tag)) in _all_traces_colorvar:
                         v, cb = _all_traces_colorvar.get((self, (i, tag)))
-                        v.trace_remove('write', cb)
+                        v.trace_vdelete('w', cb)
                         _all_traces_colorvar[(self, (i, tag))] = (var, cbname)
                     else:
                         _all_traces_colorvar[(self, (i, tag))] = (var, cbname)
@@ -96,10 +122,10 @@ def _create(self, itemType, args, kw):  # Args: (val, val, ..., cnf={})
         wid, (opt, tag_id) = key
         var, cbname = value
         if tag_id is None and cbname is None:
-            cbname = var.trace_add('write', lambda *a,
-                                   cls=self, opt=opt,
-                                   tagId=tagId, var=var:
-                                   cls.itemconfig(tagId, {opt: var.get()}))
+            cbname = var.trace_variable('w', lambda a, b, c,
+                                        cls=self, opt=opt,
+                                        tagId=tagId, var=var:
+                                        cls.itemconfig(tagId, {opt: var.get()}))
             _all_traces_colorvar[(self, (opt, tagId))] = (var, cbname)
             _all_traces_colorvar.pop((self, (opt, None)))
     return tagId
@@ -126,11 +152,11 @@ def _options(self, cnf, kw=None):
                 continue
             elif isinstance(self, tkmacosx.Button) and cnf.get('fill'):
                 i = 'fg'
-            cbname = var.trace_add('write', lambda *a, i=i, var=var,
-                                   cls=self: cls.config({i: var.get()}))
+            cbname = var.trace_variable('w', lambda a, b, c, i=i, var=var,
+                                        cls=self: cls.config({i: var.get()}))
             if (self, i) in _all_traces_colorvar:
                 v, cb = _all_traces_colorvar.get((self, i))
-                v.trace_remove('write', cb)
+                v.trace_vdelete('w', cb)
                 _all_traces_colorvar[(self, i)] = (var, cbname)
             else:
                 _all_traces_colorvar[(self, i)] = (var, cbname)
@@ -160,6 +186,7 @@ def _options(self, cnf, kw=None):
     return res
 
 
+_TK.Misc.destroy = destroy
 _TK.Misc._options = _options
 _TK.Canvas._create = _create
 _TK.Misc._configure = _configure
@@ -181,13 +208,13 @@ class ColorVar(_TK.Variable):
         If NAME matches an existing variable and VALUE is omitted
         then the existing value is retained.
         """
-        super(ColorVar, self).__init__(master, value, name)
+        _TK.Variable.__init__(self, master, value, name)
 
     def set(self, value=''):
         """Set the variable to VALUE."""
         if value.startswith('#'):
             if not bool(self._rgbstring.match(value)):
-                raise ValueError('{} is not a vaild HEX.'.format(value))
+                raise ValueError('"{}" is not a valid HEX.'.format(value))
         elif isinstance(value, str):
             try:
                 r, g, b = self._root.winfo_rgb(value)
@@ -212,7 +239,7 @@ class DictVar(_TK.Variable):
     #### Value holder for Dictionaries.
     Get a specific value by getting the key from this \
     `get(self, key=None, d=None)` method if exists in the dictionary. \n
-    if `key=None` it will returrn the complete dictionory.
+    if `key=None` it will return the complete dictionary.
     """
     _default = {}
 
@@ -239,8 +266,7 @@ class DictVar(_TK.Variable):
             return value
 
 
-def SaveVar(var: _TK.Variable, master=None, value=None, name=None, filename='data.pkl') \
-        -> (_TK.Variable):
+def SaveVar(var, master=None, value=None, name=None, filename='data.pkl'):
     """Save tkinter variable data in a pickle file and load the 
     same value when the program is executed next time. 
 
@@ -300,13 +326,13 @@ def SaveVar(var: _TK.Variable, master=None, value=None, name=None, filename='dat
     var = var(master=master, value=value, name=name)
     defaultval = var.get()  # get a default value of the variable
     update_val()
-    for mode, cbname in (var.trace_info()):
-        if mode[0] == 'write' and update_val.__name__ in cbname:
+    for mode, cbname in (var.trace_vinfo()):
+        if mode[0] == 'w' and update_val.__name__ in cbname:
             try:
-                var.trace_remove('write', cbname)
+                var.trace_vdelete('w', cbname)
             except:
                 pass
-    res = var.trace_add('write',  update_val)
+    res = var.trace_variable('w',  update_val)
     return var
 
 
