@@ -1,18 +1,22 @@
 #                       Copyright 2020 Saad Mairaj
-# 
+#
 #    Licensed under the Apache License, Version 2.0 (the "License");
 #    you may not use this file except in compliance with the License.
 #    You may obtain a copy of the License at
-# 
+#
 #        http://www.apache.org/licenses/LICENSE-2.0
-# 
+#
 #    Unless required by applicable law or agreed to in writing, software
 #    distributed under the License is distributed on an "AS IS" BASIS,
 #    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 #    See the License for the specific language governing permissions and
 #    limitations under the License.
 
-import tkinter as _TK
+import sys
+if sys.version_info.major == 2:
+    import Tkinter as _TK
+elif sys.version_info.major == 3:
+    import tkinter as _TK
 from tkmacosx.basewidget import _Frame, _Canvas, Widget
 
 
@@ -59,6 +63,7 @@ class SFrame(_Frame):
         self._geometryManager()
 
     def _mouse_scrolling(self):
+        """Internal function."""
         if self.mousewheel:
             self.bind_class(self, '<Enter>', lambda _:
                             self.bind_all('<MouseWheel>', self._on_mouse_scroll))
@@ -69,10 +74,12 @@ class SFrame(_Frame):
             self.unbind_class(self, '<Leave>')
 
     def _on_mouse_scroll(self, evt):
+        """Internal function."""
         if evt.state == 0:
             self._canvas.yview_scroll(-1*(evt.delta), 'units')
 
     def _configure_height(self, evt):
+        """Internal function."""
         if self.winfo_height() < self._canvas.winfo_height():
             self._canvas.itemconfig(
                 "window", height=self._canvas.winfo_height(), anchor='nw')
@@ -80,6 +87,7 @@ class SFrame(_Frame):
             'window', width=self._canvas.winfo_width()-self.yScroll.winfo_width())
 
     def _configure_window(self, evt):
+        """Internal function."""
         # this will update the position of scrollbar when scrolled from mousewheel.
         # fixes some bugs
         # makes scrolling more smoother
@@ -87,7 +95,7 @@ class SFrame(_Frame):
         self._canvas.configure(scrollregion=self._canvas.bbox('all'))
 
     def _geometryManager(self):
-        """Internal funtion."""
+        """Internal function."""
         # Can be done in a loop with setatr but then it underlines with red when these
         # attributes are called as they're created at runtime.
         self.grid = self.grid_configure = self._canvas.grid_configure
@@ -102,18 +110,25 @@ class SFrame(_Frame):
         self.place_info = self._canvas.place_info
 
     def configure(self, cnf=None, **kw):
+        """Configure resources of a widget.
+
+        The values for resources are specified as keyword
+        arguments. To get an overview about
+        the allowed keyword arguments call the method keys.
+        """
         kw = _TK._cnfmerge((cnf, kw))
         self._canvas['width'] = kw.pop('width', self._canvas['width'])
         self._canvas['height'] = kw.pop('height', self._canvas['height'])
         self.yScroll['width'] = kw.pop('scrollbarwidth', self.yScroll['width'])
         self.mousewheel = kw.pop('mousewheel', self.mousewheel)
         self._mouse_scrolling()
-        return super().configure(**kw)
+        return _Frame.configure(self, **kw)
 
     def cget(self, key):
+        """Return the resource value for a KEY given as string."""
         if key in ('scrollbarwidth', 'mousewheel'):
             return self.__dict__.get(key)
-        return super().cget(key)
+        return _Frame.cget(self, key)
     config = configure
     __getitem__ = cget
 
@@ -149,7 +164,7 @@ class Button(Widget):
     # all the instance of class Button will be stored in _button list.
 
     def __init__(self, master=None, cnf={}, **kw):
-        super(Button, self).__init__(master=master, cnf=cnf, **kw)
+        Widget.__init__(self, master=master, cnf=cnf, **kw)
 
     def invoke(self):
         """Invoke the command associated with the button.
@@ -198,7 +213,7 @@ class Marquee(_TK.Canvas):
         )
         kw['height'] = kw.get('height', 24)
         kw['highlightthickness'] = kw.get('highlightthickness', 0)
-        super().__init__(master=master, **kw)
+        _TK.Canvas.__init__(self, master=master, **kw)
         self.create_text(3, 1, anchor='w', tag='text', text=self.cnf.get('text'),
                          font=self.cnf.get('font'), fill=self.cnf.get('fg'))
         self.bind_class(self, '<Configure>', self.check, '+')
@@ -225,13 +240,20 @@ class Marquee(_TK.Canvas):
         if text_width + 1 + self.cnf.get('left_margin') < frame_width:
             self.after(self.cnf.get('end_delay'), self.coords,
                        'text', 3, self.winfo_height()/2)  # RESETS TEXT
-            delay = self.cnf.get('initial_delay') + self.cnf.get('end_delay') # INITITAL DEALY
+            delay = self.cnf.get('initial_delay') + \
+                self.cnf.get('end_delay')  # INITITAL DEALY
         else:
             # MOVE -1 PIXEL EVERYTIME
             self.move('text', -self.cnf.get('smoothness'), 0)
         self.after_id = self.after(delay, self.animate)
 
     def configure(self, cnf={}, **kw):
+        """Configure resources of a widget.
+
+        The values for resources are specified as keyword
+        arguments. To get an overview about
+        the allowed keyword arguments call the method keys.
+        """
         kw = _TK._cnfmerge((cnf, kw))
         self.cnf = dict(
             text=kw.pop('text', self.cnf.get('text')),
@@ -247,20 +269,29 @@ class Marquee(_TK.Canvas):
         )
         self.itemconfig('text', text=self.cnf.get('text'),
                         font=self.cnf.get('font'), fill=self.cnf.get('fg'))
-        return super().configure(**kw)
+        return _TK.Canvas.configure(self, **kw)
 
     def cget(self, key):
+        """Return the resource value for a KEY given as string."""
         if key in self.cnf.keys():
             return self.cnf['key']
-        return super().cget(key)
+        return _TK.Canvas.cget(self, key)
     __getitem__ = cget
     config = configure
 
+    def destroy(self):
+        """Destroy this widget."""
+        self.after_cancel(self.after_id)
+        return _TK.Canvas.destroy(self)
+
 # ------------------ Testing ------------------
 
 
 def demo_button():
-    from tkinter import ttk
+    if sys.version_info.major == 2:
+        import ttk
+    elif sys.version_info.major == 3:
+        from tkinter import ttk
     root = _TK.Tk()
     root.title('Mac OSX Button Demo')
     page_color = '#FFFFC6'
